@@ -74,52 +74,6 @@ class Request:
         if consts.CONTRACT in kwargs:
             self.contract = Named(**kwargs.get(consts.CONTRACT))
 
-    # Accessory methods
-    def get_marketplace_id(self):
-        return self.marketplace.id
-
-    def get_asset(self):
-        return self.asset
-
-    def get_asset_id(self):
-        return self.asset.id
-
-    def get_asset_params(self):
-        return self.asset.params
-
-    def get_asset_configuration_params(self):
-        return self.asset.configuration.params
-
-    def get_items(self):
-        return self.asset.items
-
-    def get_product_id(self):
-        return self.asset.product.id
-
-    def get_asset_connection_type(self):
-        return self.asset.connection.type
-
-    def get_hub_id(self):
-        return self.asset.connection.hub.id
-
-    def get_customer_id(self):
-        return self.asset.tiers.customer.id
-
-    def get_customer_name(self):
-        return self.asset.tiers.customer.name
-
-    def get_customer_external_id(self):
-        return self.asset.tiers.customer.external_id
-
-    def get_customer_contact_first_name(self):
-        return self.asset.tiers.customer.contact_info.contact.first_name
-
-    def get_customer_contact_last_name(self):
-        return self.asset.tiers.customer.contact_info.contact.last_name
-
-    def get_customer_contact_email(self):
-        return self.asset.tiers.customer.contact_info.contact.email
-
 
 class Param:
     """
